@@ -29,8 +29,10 @@ matplotlib.use('TkAgg')
 
 class Experimento:
 
-    def __init__(self, nombre_archivo, dimension_caja=[100, 100], cantidad_filas=10,
-                 cantidad_columnas=10, procesar_tiempo_archivo_irregular=False,
+    def __init__(self, nombre_archivo,
+                 dimension_caja=[100, 100],
+                 cantidad_filas=10, cantidad_columnas=10,
+                 procesar_tiempo_archivo_irregular=False,
                  puntos_importantes=None):
         self.nombre_archivo = nombre_archivo
         print("NOMBRE_ARCHIVO:", self.nombre_archivo, "\n TIPO_ARCHIVO:", type(self.nombre_archivo))
@@ -406,7 +408,10 @@ class Experimento:
                                        categoria="visitas_regiones_no_preferidas",
                                        datos=self.matriz_cuadriculada_solo_regiones_no_preferidas.flatten())
 
-    def calcula_arreglos_rutas_vectoriales(self, tamanio_vectorial, brinco_temporal, indice_consecuencia):
+    def calcula_arreglos_rutas_vectoriales(self,
+                                           tamanio_vectorial,
+                                           brinco_temporal,
+                                           indice_consecuencia):
         self.rutas_vectoriales.tamanio_vectorial = tamanio_vectorial
         self.rutas_vectoriales.brinco_temporal = brinco_temporal
         self.rutas_vectoriales.indice_consecuencia = indice_consecuencia
