@@ -27,6 +27,8 @@ class ConfigGrafica:
         self.brinco_temporal_consecuencias = 1
         self.tamanio_vectores_consecuencias = 1
 
+        self.tipos_regresion_lineal = ["Vecolidad",
+                                       "Aceleracin"]
         self.regresion_lineal_seleccionada = None
 
         self.regiones_preferidas_3d = [0]
