@@ -64,9 +64,7 @@ class MultiplesExperimentos:
                                                            procesar_tiempo_archivo_irregular=
                                                            self.procesar_tiempo_archivo_irregular,
                                                            puntos_importantes=self.puntos_importantes,
-                                                           objeto_a_promediar=self.objeto_a_promediar,
-                                                           tamanio_intervalo_para_promedio=self.tamanio_intervalo_para_promedio,
-                                                           genera_matriz_recurrencia=self.genera_matriz_recurrencia))
+                                                           ))
         self.procesa_diccionario_entropias()
         self.procesa_diccionario_divergencias()
 
